summaryrefslogtreecommitdiffstats
path: root/kcontrol/style/menupreview.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 04:10:07 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 04:10:07 +0000
commitfd3a982e26813f5bcc82c7e89ce6fa2ad44432bf (patch)
tree9eda848e56fcb862fdfdf479adeccd95b6fe387a /kcontrol/style/menupreview.cpp
parent02f67d0e1355b79b1806746efb0f2f640e57f13d (diff)
downloadtdebase-fd3a982e26813f5bcc82c7e89ce6fa2ad44432bf.tar.gz
tdebase-fd3a982e26813f5bcc82c7e89ce6fa2ad44432bf.zip
Revert automated changes
Sorry guys, they are just not ready for prime time Work will continue as always git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdebase@1212480 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kcontrol/style/menupreview.cpp')
-rw-r--r--kcontrol/style/menupreview.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/kcontrol/style/menupreview.cpp b/kcontrol/style/menupreview.cpp
index 64ca00fff..112f2c241 100644
--- a/kcontrol/style/menupreview.cpp
+++ b/kcontrol/style/menupreview.cpp
@@ -68,7 +68,7 @@ void MenuPreview::createPixmaps()
if (pixBlended)
pixBlended->resize( w, h );
- TQColorGroup cg = tqcolorGroup();
+ TQColorGroup cg = colorGroup();
TQColor c1 = cg.background();
TQColor c2 = cg.mid();
@@ -96,7 +96,7 @@ void MenuPreview::createPixmaps()
void MenuPreview::blendPixmaps()
{
// Rebuild pixmaps, and tqrepaint
if (pixBlended && pixBackground)
{
if (mode == Blend && pixOverlay) {
@@ -105,7 +105,7 @@ void MenuPreview::blendPixmaps()
KImageEffect::blend(src, dst, menuOpacity);
pixBlended->convertFromImage( dst );
} else if (mode == Tint) {
- TQColor clr = tqcolorGroup().button();
+ TQColor clr = colorGroup().button();
TQImage dst = pixBackground->convertToImage();
KImageEffect::blend(clr, dst, menuOpacity);
pixBlended->convertFromImage( dst );
@@ -121,7 +121,7 @@ void MenuPreview::setOpacity( int opacity )
if ((int)(menuOpacity*100) != opacity) {
menuOpacity = opacity/100.0;
blendPixmaps();
- tqrepaint( false );
+ repaint( false );
}
}
@@ -130,14 +130,14 @@ void MenuPreview::setPreviewMode( PreviewMode pvm )
if (mode != pvm) {
mode = pvm;
blendPixmaps();
- tqrepaint( false );
+ repaint( false );
}
}
void MenuPreview::paintEvent( TQPaintEvent* /* pe */ )
{
// Paint the frame and blended pixmap
- TQColorGroup cg = tqcolorGroup();
+ TQColorGroup cg = colorGroup();
int x2 = width()-1;
int y2 = height()-1;
@@ -96,7 +96,7 @@ void MenuPreview::createPixmaps()
void MenuPreview::blendPixmaps()
{
- // Rebuild pixmaps, and tqrepaint
+ // Rebuild pixmaps, and repaint
if (pixBlended && pixBackground)
{